#!/bin/bash -e
#
#  Common functions for UOSCI jobs, specific to mojo functionality.

function f_mojo_broom() {
  if [[ -d "/srv/mojo/mojo-openstack-specs/" ]]; then
    echo " - Purging /srv/mojo/mojo-openstack-specs"
    rm -rf /srv/mojo/mojo-openstack-specs/*
    echo " - Purging $MOJO_ROOT"
    rm -rf ${MOJO_ROOT:?}
  fi
}


function f_mojo_create_venv() {
  cd $UOSCI_BOT_CONTROL_ROOT/tools/mojo-openstack
  deactivate ||:
  tox
  . .tox/mojo/bin/activate
  cd $WORKSPACE
}


function f_mojo_new_project() {
# Add mojo project.
  if [[ -n "$(ls $WORKSPACE -1 | egrep '.failed|.bad')" ]]; then
    echo " ! Skipping mojo project-new, one or more preceding steps are failed or bad."
    touch $WORKSPACE/fyi-${test:0:4}.mojo-project-new.skipped
  else
    set -x
    mojo-project-new --series ${MOJO_SERIES} \
        --container containerless ${MOJO_PROJ} --mojo-root ${MOJO_ROOT} 2>&1 | tee $WORKSPACE/mojo-project-new.txt
    # Error trap
    if [[ "${PIPESTATUS[0]}" != "0" ]]; then
      echo " ! Failed to create new mojo project."
      touch $WORKSPACE/fyi-${test:0:4}.${test}-mojo-project-new.failed
      exit 1
    fi
    set +x
  fi
}


function f_mojo_new_workspace() {
# Add mojo workspace.
  if [[ -n "$(ls $WORKSPACE -1 | egrep '.failed|.bad')" ]]; then
    echo " ! Skipping mojo workspace-new, one or more preceding steps are failed or bad."
    touch $WORKSPACE/fyi-${test:0:4}.mojo-workspace-new.skipped
  else
    set -x
    mojo --mojo-root ${MOJO_ROOT} workspace-new --project ${MOJO_PROJ} --series ${MOJO_SERIES} \
        --stage ${MOJO_SPEC} ${MOJO_OPENSTACK_SPECS_REPO} ${MOJO_WKSP} \
        2>&1 | tee $WORKSPACE/mojo-workspace-new.txt

    # Error trap
    if [[ "${PIPESTATUS[0]}" != "0" ]]; then
      echo " ! Failed to create new mojo workspace."
      touch $WORKSPACE/fyi-${test:0:4}.${test}-mojo-workspace-new.failed
      exit 1
    fi
    set +x
  fi
}


function f_mojo_run() {
# Run mojo, run!
  if [[ -n "$(ls $WORKSPACE -1 | egrep '.failed|.bad')" ]]; then
    echo " ! Skipping mojo run, one or more preceding steps are failed or bad."
    touch $WORKSPACE/fyi-${test:0:4}.mojo-run.skipped
  else
    # Construct network env vars based on bootstrap node 0
    f_openstack_set_network_env_vars
    #f_amulet_set_network_env_vars
    set -x
    mojo --mojo-root ${MOJO_ROOT} run --project ${MOJO_PROJ} --series ${MOJO_SERIES} \
        --stage ${MOJO_SPEC} ${MOJO_OPENSTACK_SPECS_REPO} ${MOJO_WKSP} \
        2>&1 | tee $WORKSPACE/mojo-run.txt

    # Error trap
    if [[ "${PIPESTATUS[0]}" != "0" ]]; then
      echo " ! Mojo run manifest failed."
      touch $WORKSPACE/fyi-${test:0:4}.${test}-mojo-run.failed
    fi
    set +x
  fi
}


function f_mojo_handle_env_vars() {
# Validate and process mojo runner environment variables.

  # Basic confirmation of non-null values.
  options="MOJO_OPENSTACK_SPECS_REPO MOJO_SPEC MOJO_SERIES"
  for option in $options; do
    if [[ -z "${!option}" ]]; then
      echo " ! Failing on null option: ${option}"
      touch $WORKSPACE/fyi-${test:0:4}.${test}-mojo-env-vars.failed
    else
      echo "${option} ok: ${!option}"
    fi
  done

  # Check for custom mojo spec value.
  if [[ "$MOJO_SPEC" == "MOJO_SPEC_CUSTOM" ]]; then
    if [[ -n "$MOJO_SPEC_CUSTOM" ]]; then
      MOJO_SPEC="${MOJO_SPEC_CUSTOM}"
      echo "Using custom mojo spec: ${MOJO_SPEC}"
    else
      echo " ! Instructed to use a custom spec but did not provide a custom spec value!"
      touch $WORKSPACE/fyi-${test:0:4}.${test}-mojo-env-vars.failed
    fi
  fi

  # Fatal if error.  Aborts job build.
  f_set_build_descr
  f_check_fail
}
